==> biocViews_1.18.1.zip: biocViews/doc/createReposHtml.R <==
###################################################
### chunk number 1: 
###################################################
#line 42 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphLYXjc/R.INSTALL37abd7e/biocViews/inst/doc/createReposHtml.Rnw"
library("biocViews")


###################################################
### chunk number 2: params
###################################################
#line 79 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphLYXjc/R.INSTALL37abd7e/biocViews/inst/doc/createReposHtml.Rnw"
reposRoot <- "path/to/reposRoot"
## The names are essential
contribPaths <- c(source="src/contrib",
                  win.binary="bin/windows/contrib/2.6",
                  win64.binary="bin/windows64/contrib/2.6",
                  mac.binary.leopard="bin/macosx/leopard/contrib/2.6")


###################################################
### chunk number 3: extractVigs eval=FALSE
###################################################
## #line 93 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphLYXjc/R.INSTALL37abd7e/biocViews/inst/doc/createReposHtml.Rnw"
## extractVignettes(reposRoot, contribPaths["source"])


###################################################
### chunk number 4: controlFiles eval=FALSE
###################################################
## #line 103 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphLYXjc/R.INSTALL37abd7e/biocViews/inst/doc/createReposHtml.Rnw"
## genReposControlFiles(reposRoot, contribPaths)


###################################################
### chunk number 5: exampleOfHtmlDesign eval=FALSE
###################################################
## #line 163 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphLYXjc/R.INSTALL37abd7e/biocViews/inst/doc/createReposHtml.Rnw"
## ## Define classes like this for each logical document chunk
## setClass("pdAuthorMaintainerInfo", contains="PackageDetail")
## setClass("pdVignetteInfo", contains="PackageDetail")
## 
## ## Then define a htmlValue method
## setMethod("htmlValue", signature(object="pdDescriptionInfo"),
##           function(object) {
##               node <- xmlNode("p", cleanText(object@Description),
##                               attrs=c(class="description"))
##               node
##           })
## 
## ## Then you can make use of all this...
## ## Assume object contains a PackageDetail instance
## authorInfo <- as(object, "pdAuthorMaintainerInfo")
## dom$addNode(htmlValue(authorInfo))
##

==> biocViews_1.22.0.zip: biocViews/doc/createReposHtml.R <==
### R code from vignette source 'createReposHtml.Rnw'

###################################################
### code chunk number 1: createReposHtml.Rnw:41-42
###################################################
library("biocViews")


###################################################
### code chunk number 2: params
###################################################
reposRoot <- "path/to/reposRoot"
## The names are essential
contribPaths <- c(source="src/contrib",
                  win.binary="bin/windows/contrib/2.6",
                  win64.binary="bin/windows64/contrib/2.6",
                  mac.binary.leopard="bin/macosx/leopard/contrib/2.6")


###################################################
### code chunk number 3: extractVigs (eval = FALSE)
###################################################
## extractVignettes(reposRoot, contribPaths["source"])


###################################################
### code chunk number 4: controlFiles (eval = FALSE)
###################################################
## genReposControlFiles(reposRoot, contribPaths)


###################################################
### code chunk number 5: exampleOfHtmlDesign (eval = FALSE)
###################################################
## ## Define classes like this for each logical document chunk
## setClass("pdAuthorMaintainerInfo", contains="PackageDetail")
## setClass("pdVignetteInfo", contains="PackageDetail")
## 
## ## Then define a htmlValue method
## setMethod("htmlValue", signature(object="pdDescriptionInfo"),
##           function(object) {
##               node <- xmlNode("p", cleanText(object@Description),
##                               attrs=c(class="description"))
##               node
##           })
## 
## ## Then you can make use of all this...
## ## Assume object contains a PackageDetail instance
## authorInfo <- as(object, "pdAuthorMaintainerInfo")
## dom$addNode(htmlValue(authorInfo))
##
